@@ -1,4 +1,4 @@
-#include "sampling.h"
+#include "bas.h"
 
 NODEPTR make_node(double pr) {
   NODEPTR newnode;
@@ -26,18 +26,18 @@ void deallocate_tree(struct Node *tree) {
 
 
 void insert_model_tree(struct Node *tree, struct Var *vars,  int n, int *model, int num_models) {
-  int i, bit; 
+  int i, bit;
   NODEPTR branch;
 
   branch = tree;
-  
+
   // added bit to add counts //
   for (i = 0; i< n; i++) {
       bit =  model[vars[i].index];
-      
+
       if (bit == 1) {
         branch->counts_1 += 1;
-	if (i < n-1 && branch->one == NULL) 
+	if (i < n-1 && branch->one == NULL)
 	  branch->one = make_node(-1.0);
 	if (i == n-1 && branch->one == NULL) {
 	  branch->one = make_node(0.0);
@@ -52,7 +52,7 @@ void insert_model_tree(struct Node *tree, struct Var *vars,  int n, int *model,
 	  branch->zero = make_node(0.0);
 	}
 	branch = branch->zero;
-      } 
+      }
   }
   branch->where = num_models;
 }
@@ -131,7 +131,7 @@ int update_probs(double *probs, struct Var *vars, int m, int k, int p) {
 	update = 0;
 	for (i=0, diff=0.0; i <p; i++){
 		diff += (probs[vars[i].index] - vars[i].prob)*(probs[vars[i].index] - vars[i].prob);
-	}	
+	}
 	if (sqrt(diff/ (double) p) >  .025) {
 		update = 1;
 		for (i = 0;   i < p; i++) {
@@ -159,8 +159,8 @@ void update_MCMC_probs(double *probs, struct Var *vars, int n, int p) {
     }
 }
 
-// used with glm_*.c   
-void SetModel1(SEXP Rfit, SEXP Rmodel_m, 
+// used with glm_*.c
+void SetModel1(SEXP Rfit, SEXP Rmodel_m,
 	       SEXP beta, SEXP se, SEXP modelspace,
 	       SEXP deviance, SEXP R2, SEXP Q, SEXP Rintercept, int m) {
 	SET_ELEMENT(beta, m, getListElement(getListElement(Rfit, "fit"),"coefficients"));
